## Description

Please include a summary of the changes and the related issue, including the relevant motivation and context. Also list any dependencies that are required for this change.

## Issue number and link:

## PR checks:

- [ ] Have you followed our [PR guidelines](https://bcg-x-official.github.io/artkit/contributor_guide/how_to_contribute.html#pull-request-pr-guidelines) document
- [ ] Have you checked to ensure there aren't other open [Pull Requests](https://github.com/BCG-X-Official/artkit/pulls) for the same update/change?
- [ ] Have you set these PR fields: Reviewers, Assignees, Labels, Milestones
- [ ] Have you updated `RELEASE_NOTES.rst`, if applicable?
- [ ] Have you updated existing and/or created new unit tests for your changes?
